@@ -1,11 +1,12 @@
 #!/usr/bin/env /usr/bin/python3
 
 import logging
-from imghdr import what
+from argparse import Namespace
 from os import walk, access, R_OK
 from pathlib import Path
 from typing import Callable, List, Optional
 
+from filetype import guess
 from pillow_heif import open_heif, register_heif_opener
 from pillow_heif.error import HeifError
 
@@ -13,19 +14,18 @@ from duplicate_images.common import path_with_parent
 from duplicate_images.function_types import Results
 from duplicate_images.hash_store import PickleHashStore
 from duplicate_images.image_pair_finder import ImagePairFinder, PairFinderOptions
-from duplicate_images.logging import setup_logging
+from duplicate_images.log import setup_logging
 from duplicate_images.methods import ACTIONS_ON_EQUALITY, IMAGE_HASH_ALGORITHM
 from duplicate_images.parse_commandline import parse_command_line
 
-
 register_heif_opener()
 
 
 def is_image_file(filename: Path) -> bool:
     """Returns True if filename is a readable image file"""
     if access(filename, R_OK) and not filename.is_symlink():
-        if what(filename) is not None or is_heif_file(filename):
-            return True
+        kind = guess(filename)
+        return kind is not None and kind.mime.startswith('image/')
     return False
 
 
@@ -67,11 +67,12 @@ def get_matches(
         ).get_pairs()
 
 
-def execute_actions(matches: Results, action_name: str) -> None:
-    action_equal = ACTIONS_ON_EQUALITY[action_name]
-    for match in sorted(matches):
+def execute_actions(matches: Results, args: Namespace) -> None:
+    action_equal = ACTIONS_ON_EQUALITY[args.on_equal]
+
+    for pair in sorted(matches):
         try:
-            action_equal(match)
+            action_equal(args, pair)
         except FileNotFoundError:
             continue
 
@@ -88,7 +89,7 @@ def main() -> None:
             options=options, hash_store_path=Path(args.hash_db) if args.hash_db else None
         )
         logging.info('%d matches', len(matches))
-        execute_actions(matches, args.on_equal)
+        execute_actions(matches, args)
     except KeyboardInterrupt:
         pass
 
