@@ -7,22 +7,25 @@ from multiprocessing.pool import ThreadPool as Pool
 from pathlib import Path
 from typing import Dict, List, Iterator, Optional
 
+from imagehash import ImageHash
 from PIL import Image
 
 from duplicate_images.common import path_with_parent
 from duplicate_images.function_types import Cache, CacheEntry, HashFunction, ImagePair, Results
+from duplicate_images.methods import get_hash_size_kwargs
 from duplicate_images.progress_bar_manager import ProgressBarManager
 
 
 @dataclass(frozen=True)
 class PairFinderOptions:
     max_distance: int = 0
+    hash_size: Optional[int] = None
     show_progress_bars: bool = False
     parallel: bool = False
 
     @classmethod
     def from_args(cls, args: Namespace):
-        return cls(args.max_distance, args.progress, args.parallel)
+        return cls(args.max_distance, args.hash_size, args.progress, args.parallel)
 
 
 class ImagePairFinder:
@@ -46,6 +49,7 @@ class ImagePairFinder:
     ) -> None:
         self.files = files
         self.algorithm = hash_algorithm
+        self.hash_size_kwargs = get_hash_size_kwargs(hash_algorithm, options.hash_size)
         self.max_distance = options.max_distance
         self.hash_store = hash_store if hash_store is not None else {}
         self.progress_bars = ProgressBarManager.create(len(files), options.show_progress_bars)
@@ -90,14 +94,14 @@ class ImagePairFinder:
             if cached is not None:
                 return file, cached
 
-            image_hash = self.algorithm(Image.open(file))
+            image_hash = self.algorithm(Image.open(file), **self.hash_size_kwargs)
             self.hash_store[file] = image_hash
             return file, image_hash
         except OSError as err:
             logging.warning('%s: %s', path_with_parent(file), err)
             return file, None
 
-    def get_hashes(self, image_files: List[Path]) -> Dict[Path, int]:
+    def get_hashes(self, image_files: List[Path]) -> Dict[Path, ImageHash]:
         return {
             file: image_hash for file, image_hash in self.precalculate_hashes(image_files)
             if image_hash is not None
